import * as React from 'react';
import { Platform, StyleSheet, View } from 'react-native';
/*
 * the `left` prop can be provided to HeaderButtons as well as OverflowMenu
 * this will render some extra margins on the corresponding side
 * but must be considered only once which is the job of this Context
 * */

export const ButtonsExtraMarginContext = /*#__PURE__*/React.createContext('toBeHandled');
export const ButtonsWrapper = _ref => {
  let {
    left,
    children,
    style
  } = _ref;
  const marginStatus = React.useContext(ButtonsExtraMarginContext);
  const extraSideMargin = marginStatus === 'alreadyHandled' ? undefined : getMargin(left);
  return /*#__PURE__*/React.createElement(ButtonsExtraMarginContext.Provider, {
    value: "alreadyHandled"
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.row, extraSideMargin, style]
  }, children));
};
const getMargin = left => {
  return left ? styles.extraEdgeMarginOnLeft : styles.extraEdgeMarginOnRight;
};
const styles = StyleSheet.create({
  row: {
    flexDirection: 'row',
    justifyContent: 'flex-end',
    ...Platform.select({
      android: {
        columnGap: 18
      },
      default: {
        columnGap: 24
      }
    })
  },
  extraEdgeMarginOnLeft: {
    ...Platform.select({
      android: {
        marginLeft: 5
      },
      default: {
        marginLeft: 4
      }
    })
  },
  extraEdgeMarginOnRight: {
    ...Platform.select({
      android: {
        marginRight: 14
      },
      default: {
        marginRight: 15
      }
    })
  }
});
//# sourceMappingURL=ButtonsWrapper.js.map